package jrummikub.model;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import static jrummikub.model.StoneColor.*;

/**
 * The overall game settings
 */
public class GameSettings {
	private List<PlayerSettings> players = new ArrayList<PlayerSettings>();

	private int initialMeldThreshold;
	private int jokerPoints;
	private int jokerNumber;
	private int highestCard;
	private int stoneSets;
	private boolean noLimits;
	private Set<StoneColor> stoneColors;

	/**
	 * Creates new GameSettings with default values
	 */
	public GameSettings() {
		initialMeldThreshold = 30;
		jokerPoints = 50;
		jokerNumber = 2;
		highestCard = 13;
		stoneSets = 2;
		noLimits = false;
		stoneColors = new HashSet<StoneColor>(Arrays.asList(BLACK, BLUE,
				ORANGE, RED));
	}

	/**
	 * Returns the list containing the settings of all players
	 * 
	 * @return the player settings list
	 */
	public List<PlayerSettings> getPlayerList() {
		return players;
	}

	/**
	 * Sets the initial meld threshold
	 * 
	 * @param value
	 *            the value to set
	 */
	public void setInitialMeldThreshold(int value) {
		initialMeldThreshold = value;
	}

	/**
	 * Returns the initial meld threshold
	 * 
	 * @return the threshold
	 */
	public int getInitialMeldThreshold() {
		return initialMeldThreshold;
	}

	/**
	 * Sets the points counted for a joker
	 * 
	 * @param value
	 *            the value to set
	 */
	public void setJokerPoints(int value) {
		jokerPoints = value;
	}

	/**
	 * Returns the points counted for a joker
	 * 
	 * @return the points
	 */
	public int getJokerPoints() {
		return jokerPoints;
	}

	/**
	 * Sets the number of jokers in game
	 * 
	 * @param value
	 */
	public void setJokerNumber(int value) {
		jokerNumber = value;
	}

	/**
	 * Returns the number of jokers
	 * 
	 * @return the number of jokers
	 */
	public int getJokerNumber() {
		return jokerNumber;
	}

	/**
	 * Return the highest card value in use
	 * 
	 * @return highest card value
	 */
	public int getHighestCard() {
		return highestCard;
	}

	/**
	 * Set the highest card value in use
	 * 
	 * @param highestCard
	 *            highest card value
	 */
	public void setHighestCard(int highestCard) {
		this.highestCard = highestCard;
	}

	/**
	 * Get the number of sets of stones in use
	 * 
	 * @return sets of stones in use
	 */
	public int getStoneSets() {
		return stoneSets;
	}

	/**
	 * Set the number of sets of stones in use
	 * 
	 * @param stoneSets
	 *            sets of stones in use
	 */
	public void setStoneSets(int stoneSets) {
		this.stoneSets = stoneSets;
	}

	/**
	 * Use "No-Limits" rules
	 * 
	 * @return whether No-Limits rules are used
	 */
	public boolean isNoLimits() {
		return noLimits;
	}

	/**
	 * Set whether "No-Limits" rules are used
	 * 
	 * @param noLimits
	 *            use no limit rules
	 */
	public void setNoLimits(boolean noLimits) {
		this.noLimits = noLimits;
	}

	/**
	 * Get stone colors used
	 * 
	 * @return used stone colors
	 */
	public Set<StoneColor> getStoneColors() {
		return stoneColors;
	}

	/**
	 * Set stone colors used
	 * 
	 * @param stoneColors
	 *            used stone colors
	 */
	public void setStoneColors(Set<StoneColor> stoneColors) {
		this.stoneColors = stoneColors;
	}
}
