package jrummikub.model;

/**
 * {@link Stone} Position class to determine positions on {@link Table} or
 * {@link Hand}
 */

public class Position {

	private float x;
	private float y;

	/**
	 * Create a new position by specifying the coordinates
	 * 
	 * @param x
	 *          x coordinate
	 * @param y
	 *          y coordinate
	 */
	public Position(float x, float y) {
		this.x = x;
		this.y = y;
	}

	/**
	 * Get the x coordinate of the position
	 * 
	 * @return x coordinate
	 */
	public float getX() {
		return x;
	}

	/**
	 * Get the y coordinate of the position
	 * 
	 * @return y coordinate
	 */
	public float getY() {
		return y;
	}

	@Override
	public String toString() {
		return "Position[x=" + x + ",y=" + y + "]";
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Position other = (Position) obj;
		if (Float.floatToIntBits(x) != Float.floatToIntBits(other.x))
			return false;
		if (Float.floatToIntBits(y) != Float.floatToIntBits(other.y))
			return false;
		return true;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + Float.floatToIntBits(x);
		result = prime * result + Float.floatToIntBits(y);
		return result;
	}

}
